import asyncio
import subprocess

import click

from argos import logging
from argos.agent import run_agent
from argos.logging import logger


@click.group()
def cli():
    pass


@cli.command()
@click.option("--server", required=True, help="Server URL")
@click.option("--auth", required=True, help="The authentication token")
@click.option("--max-tasks", default=10, help="Maximum number of concurrent tasks")
@click.option(
    "--wait-time",
    default=10,
    help="Wait time (in seconds) between two polls on the server",
)
@click.option(
    "--log-level",
    default="INFO",
    type=click.Choice(logging.LOG_LEVELS, case_sensitive=False),
)
def agent(server, auth, max_tasks, wait_time, log_level):
    """Runs an agent"""
    logging.set_log_level(log_level)
    asyncio.run(run_agent(server, auth, max_tasks, wait_time))


@cli.command()
@click.option("--host", default="127.0.0.1", help="Host to bind")
@click.option("--port", default=8000, type=int, help="Port to bind")
@click.option("--reload", is_flag=True, help="Enable hot reloading")
def server(host, port, reload):
    """Starts the server."""
    command = ["uvicorn", "argos.server:app", "--host", host, "--port", str(port)]
    if reload:
        command.append("--reload")
    subprocess.run(command)


if __name__ == "__main__":
    cli()
